@@ -1,12 +1,12 @@
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from . import commands
 
 
 urlpatterns = [
 
-    url(
+    re_path(
         r'^$',
         commands.EntryPointCommands.as_view(),
         name='entrypoint'),
